@@ -2,6 +2,7 @@ use strict;
 use warnings;
 
 use Device::Chip::MAX7219;
+use Device::Chip::Adapter;
 
 use Time::HiRes qw( sleep time );
 use POSIX qw( strftime );
@@ -12,17 +13,10 @@ GetOptions(
    'adapter|A=s' => \( my $ADAPTER = "BusPirate" ),
 ) or exit 1;
 
-my $adapter = do {
-   my $class = "Device::Chip::Adapter::$ADAPTER";
-
-   ( my $file = "$class.pm" ) =~ s{::}{/}g;
-   require $file;
-
-   $class->new;
-};
-
 my $max = Device::Chip::MAX7219->new;
-$max->connect( $adapter )->get;
+$max->mount(
+   Device::Chip::Adapter->new_from_description( $ADAPTER )
+)->get;
 
 $max->protocol->power(1)->get;
 END {
