@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2014-2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2014-2016 -- leonerd@leonerd.org.uk
 
 package Device::Chip::MAX7219;
 
@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( Device::Chip );
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Carp;
 
@@ -23,20 +23,20 @@ C<Device::Chip::MAX7219> - chip driver for a F<MAX7219>
 
  use Device::Chip::MAX7219;
 
- my $max = Device::Chip::MAX7219->new;
- $max->mount( Device::Chip::Adapter::...->new )->get;
+ my $chip = Device::Chip::MAX7219->new;
+ $chip->mount( Device::Chip::Adapter::...->new )->get;
 
- $max->power(1)->get;
+ $chip->power(1)->get;
 
- $max->intensity( 2 )->get;
- $max->limit( 8 )->get;
+ $chip->intensity( 2 )->get;
+ $chip->limit( 8 )->get;
 
- $max->displaytest( 1 )->get;
- $max->shutdown( 0 )->get;
+ $chip->displaytest( 1 )->get;
+ $chip->shutdown( 0 )->get;
 
  sleep 3;
 
- $max->displaytest( 0 )->get;
+ $chip->displaytest( 0 )->get;
 
 =head1 DESCRIPTION
 
@@ -61,17 +61,12 @@ sub new
    return $self;
 }
 
-sub mount
+sub SPI_options
 {
-   my $self = shift;
-   $self->SUPER::mount( @_ )->then( sub {
-      my $self = shift;
-
-      $self->protocol->configure(
-         mode        => 0,
-         max_bitrate => 1E6,
-      )->then_done( $self );
-   });
+   return (
+      mode        => 0,
+      max_bitrate => 1E6,
+   );
 }
 
 use constant {
@@ -96,7 +91,9 @@ sub _writereg
 
 =cut
 
-=head2 $max->write_bcd( $digit, $val )->get
+=head2 write_bcd
+
+   $chip->write_bcd( $digit, $val )->get
 
 Writes the value at the given digit, setting it to BCD mode if not already so.
 C<$val> should be a single digit number or string, or one of the special
@@ -132,7 +129,9 @@ sub write_bcd
    });
 }
 
-=head2 $max->write_raw( $digit, $bits )->get
+=head2 write_raw
+
+   $chip->write_raw( $digit, $bits )->get
 
 Writes the value at the given digit, setting the raw column lines to the 8-bit
 value given.
@@ -159,7 +158,9 @@ sub write_raw
    });
 }
 
-=head2 $max->write_hex( $digit, $val )->get
+=head2 write_hex
+
+   $chip->write_hex( $digit, $val )->get
 
 Similar to C<write_bcd>, but uses a segment decoder written in code rather
 than on the chip itself, to turn values into sets of segments to display. This
@@ -179,7 +180,9 @@ sub write_hex
    $self->write_raw( $digit, $bits + ( $dp ? 0x80 : 0 ) );
 }
 
-=head2 $max->set_decode( $bits )->get
+=head2 set_decode
+
+   $chip->set_decode( $bits )->get
 
 Directly sets the decode mode of all the digits at once. This is more
 efficient for initialising digits into BCD or raw mode, than individual calls
@@ -194,7 +197,9 @@ sub set_decode
    $self->_writereg( REG_DECODE, $self->{decode} = $bits );
 }
 
-=head2 $max->intensity( $value )->get
+=head2 intensity
+
+   $chip->intensity( $value )->get
 
 Sets the intensity register. C<$value> must be between 0 and 15, with higher
 values giving a more intense output.
@@ -207,7 +212,9 @@ sub intensity
    $self->_writereg( REG_INTENSITY, @_ );
 }
 
-=head2 $max->limit( $columns )->get
+=head2 limit
+
+   $chip->limit( $columns )->get
 
 Sets the scan limit register. C<$value> must be between 1 and 8, to set
 between 1 and 8 digits. This should only be used to adjust for the number of
@@ -228,7 +235,9 @@ sub limit
    $self->_writereg( REG_LIMIT, $columns - 1 );
 }
 
-=head2 $max->shutdown( $off )->get
+=head2 shutdown
+
+   $chip->shutdown( $off )->get
 
 Sets the shutdown register, entirely blanking the display and turning off all
 output if set to a true value, or restoring the display to its previous
@@ -246,7 +255,9 @@ sub shutdown
    $self->_writereg( REG_SHUTDOWN, !$off );
 }
 
-=head2 $max->displaytest( $on )->get
+=head2 displaytest
+
+   $chip->displaytest( $on )->get
 
 Sets the display test register, overriding the output control and turning on
 every LED if set to a true value, or restoring normal operation if set to
